@@ -17,9 +17,11 @@
 //! ```rust
 //! # let guard = pprof::ProfilerGuard::new(100).unwrap();
 //!if let Ok(report) = guard.report().build() {
-//!    println!("report: {}", &report);
+//!    println!("report: {:?}", &report);
 //!};
 //! ```
+//!
+//! You can find more details in [README.md](https://github.com/tikv/pprof-rs/blob/master/README.md)
 
 /// Define the MAX supported stack depth. TODO: make this variable mutable.
 pub const MAX_DEPTH: usize = 32;
@@ -27,6 +29,7 @@ pub const MAX_DEPTH: usize = 32;
 /// Define the MAX supported thread name length. TODO: make this variable mutable.
 pub const MAX_THREAD_NAME: usize = 16;
 
+#[allow(clippy::uninit_assumed_init)]
 mod collector;
 mod error;
 mod frames;
@@ -40,9 +43,15 @@ pub use self::frames::{Frames, Symbol};
 pub use self::profiler::ProfilerGuard;
 pub use self::report::{Report, ReportBuilder};
 
+#[cfg(feature = "flamegraph")]
+pub use inferno::flamegraph;
+
 #[cfg(feature = "protobuf")]
 pub mod protos {
     pub use prost::Message;
 
     include!(concat!(env!("OUT_DIR"), "/perftools.profiles.rs"));
 }
+
+#[cfg(feature = "criterion")]
+pub mod criterion;
